@@ -33,40 +33,13 @@ def readImg(image_path, resized_img_size=None, channels=1):
         image_array = cv.resize(image_array, (resized_img_size,resized_img_size))
     return image_array
 
-def compute_mean(DIR, channels):
-    if channels == 3:
-        rMean, gMean, bMean = 0,0,0
-    if channels == 1:
-        mean = 0
-    count = 0
-
-    if os.path.exists(DIR) is False:
-        raise ValueError('The specified directory does not exist', DIR)
-
-    for root, _, files in os.walk(DIR):
-        for file in files:
-            if file.endswith('.png') or file.endswith('.jpg'):
-                count += 1
-                filepath = root + os.sep + file
-                img = cv.imread(filepath)
-                if channels == 3:
-                    b,g,r = cv.mean(img.astype('float32'))[:3]
-                    rMean += r
-                    bMean += b
-                    gMean += g
-                if channels == 1:
-                    mean += cv.mean(img.astype('float32'))[0]
-
-    # Computing average mean
-    if channels == 3:
-        rMean /= count
-        bMean /= count 
-        gMean /= count
-        return rMean, bMean, gMean
-
-    if channels == 1:
-        mean /= count
-        return mean
+def get_classes_from_dir(DIR):
+    if len(os.listdir(DIR)) == 0:
+        raise ValueError('[ERROR] The specified directory does not seem to have any folders in it')
+    else:
+        classes = [i for i in os.listdir(DIR)]
+        return classes
+        
 
 def saveNumpy(name, x):
     """
@@ -82,6 +55,7 @@ def saveNumpy(name, x):
 
 def train_val_split(X,y,val_ratio=.2):
     """
+    Do not use if mean subtraction is being employed
     Returns X_train, X_val, y_train, y_val
     """
     try:
@@ -91,7 +65,13 @@ def train_val_split(X,y,val_ratio=.2):
     except ModuleNotFoundError:
         print('[ERROR] The Sklearn Python package needs to be installed')
 
-def extract_frames(input_folder, output_folder, IMG_SIZE=None, label_counter = None, video_count=None, frames_per_sec=None, dest_filetype='jpg'):
+def extract_frames(input_folder, 
+                   output_folder, 
+                   IMG_SIZE=None, 
+                   label_counter = None, 
+                   video_count=None, 
+                   frames_per_sec=None, 
+                   dest_filetype='jpg'):
     """ Function to extract frames from videos within a directory
     and save them as separate frames in an output directory.
     Args:
@@ -298,11 +278,11 @@ def toMatplotlib(image):
     """
     return cv.cvtColor(image, cv.COLOR_BGR2RGB)
 
-def url_to_image(url, flag=cv.IMREAD_COLOR):
+def url_to_image(url):
     # Converts the image to a Numpy array and reads it in OpenCV
     response = urlopen(url)
     image = np.asarray(bytearray(response.read()), dtype="uint8")
-    image = cv.imdecode(image, flag)
+    image = cv.imdecode(image, cv.IMREAD_COLOR)
 
     return image
 
